emphasis

# XMLRésuméLibrary: User Guide

email | Element Reference | employer

## Name

emphasis — An emphasized block of text

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `emphasis` element is an inline element that indicates that the text it contains should be emphasized.

### Presentation

The presentation of text contained in this element varies depending on the output format.

HTML

  Rendered as bold (using the `<strong>` tag) by default. Presentation may be overridden by creating or modifying a CSS stylesheet that formats the `emphasis` class.

Text

  Text is surrounded in *astrisks* by default. May be overridden by specifying the `text.emphasis.start` and `text.emphasis.end` parameters when processing the résumé with an XSLT processor like Xalan or Saxon.

XSL-FO/PDF

  Rendered as bold text.

### Parents

`emphasis` may be contained in these elements: `achievement`, `employer`, `institution`, `organization`, `para`, `project`, `skill`

## Examples

    <para>
      I really, really, <emphasis>really</emphasis> want a job.
    </para>

    <skill>
      I am <emphasis>extremely</emphasis> at using rocket-powered cheese graters.
    </skill>

email | Element Reference | employer